@@ -47,11 +47,9 @@
 
 #define PDEBUG(pix) (g_print ("file %s: line %d (%s): Setting pixbuf to %i %i\n", __FILE__, __LINE__, __PRETTY_FUNCTION__, gdk_pixbuf_get_width (pix), gdk_pixbuf_get_height (pix)))
 
-static GtkWidget *preview_widget = NULL;
 static gboolean gdk_pixbuf_xlib_inited = FALSE;
 
 typedef struct _Renderer Renderer;
-typedef struct _ApplierPreferences ApplierPreferences;
 
 enum {
 	ARG_0,
@@ -59,8 +57,9 @@ enum {
 
 struct _ApplierPrivate 
 {
-	ApplierPreferences *root_prefs;
-	ApplierPreferences *preview_prefs;
+	GtkWidget          *preview_widget;
+	Preferences        *root_prefs;
+	Preferences        *preview_prefs;
 
 	GdkPixbuf          *wallpaper_pixbuf;
 	gchar              *wallpaper_filename;
@@ -76,7 +75,8 @@ struct _Renderer
 	gboolean            is_root;
 	gboolean            is_set;
 
-	ApplierPreferences *prefs;
+	GtkWidget          *widget;
+	Preferences        *prefs;
 
 	gint                x;         /* Geometry relative to pixmap */
 	gint                y;
@@ -104,34 +104,6 @@ struct _Renderer
 	Pixmap              pixmap;
 };
 
-typedef enum _orientation_t {
-	ORIENTATION_SOLID, ORIENTATION_HORIZ, ORIENTATION_VERT
-} orientation_t;
-
-typedef enum _wallpaper_type_t {
-	WPTYPE_TILED, WPTYPE_CENTERED, WPTYPE_SCALED_ASPECT,
-	WPTYPE_SCALED, WPTYPE_EMBOSSED
-} wallpaper_type_t;
-
-
-struct _ApplierPreferences 
-{
-	int ref_count;
-
-	gboolean          gradient_enabled;
-	gboolean          wallpaper_enabled;
-	orientation_t     orientation;
-	wallpaper_type_t  wallpaper_type;
-
-	GdkColor         *color1;
-	GdkColor         *color2;
-
-	gchar            *wallpaper_filename;
-
-	gboolean          adjust_opacity;
-	gint              opacity;
-};
-
 static GtkObjectClass *parent_class;
 
 static void applier_init             (Applier *prefs);
@@ -145,16 +117,16 @@ static void applier_get_arg          (GtkObject *object,
 				      guint arg_id);
 
 static void run_render_pipeline      (Renderer *renderer, 
-				      ApplierPreferences *old_prefs,
-				      ApplierPreferences *new_prefs,
+				      Preferences *old_prefs,
+				      Preferences *new_prefs,
 				      GdkPixbuf *wallpaper_pixbuf);
 static void draw_disabled_message    (GtkWidget *widget);
 
-static Renderer *renderer_new        (gboolean is_root);
+static Renderer *renderer_new        (Applier *applier, gboolean is_root);
 static void renderer_destroy         (Renderer *renderer);
 
 static void renderer_set_prefs       (Renderer *renderer,
-				      ApplierPreferences *prefs);
+				      Preferences *prefs);
 static void renderer_set_wallpaper   (Renderer *renderer, 
 				      GdkPixbuf *wallpaper_pixbuf);
 
@@ -185,22 +157,15 @@ static void tile_composite           (GdkPixbuf *dest, GdkPixbuf *src,
 				      gint alpha_value);
 
 static gboolean render_gradient_p    (Renderer *renderer,
-				      ApplierPreferences *prefs);
-static gboolean render_small_pixmap_p (ApplierPreferences *prefs);
+				      Preferences *prefs);
+static gboolean render_small_pixmap_p (Preferences *prefs);
 
 static Pixmap make_root_pixmap       (gint width, gint height);
 static void set_root_pixmap          (Pixmap pixmap);
 
 static gboolean is_nautilus_running  (void);
 
-/* preferences stuff -- easier than making an object */
-static ApplierPreferences* applier_preferences_pb_new (Bonobo_PropertyBag pb, CORBA_Environment *ev);
-static ApplierPreferences* applier_preferences_db_new (Bonobo_ConfigDatabase db, CORBA_Environment *ev);
-static void applier_preferences_ref (ApplierPreferences *prefs);
-static void applier_preferences_unref (ApplierPreferences *prefs);
-static void applier_preferences_free (ApplierPreferences *prefs);
-
-static GdkColor* bonobo_color_to_gdk (Bonobo_Config_Color *color);
+static void output_compat_prefs (Preferences *prefs);
 
 guint
 applier_get_type (void)
@@ -322,9 +287,9 @@ applier_destroy (GtkObject *object)
 		renderer_destroy (applier->private->root_renderer);
 
 	if (applier->private->root_prefs != NULL)
-		applier_preferences_unref (applier->private->root_prefs);
+		gtk_object_unref (GTK_OBJECT (applier->private->root_prefs));
 	if (applier->private->preview_prefs != NULL)
-		applier_preferences_unref (applier->private->preview_prefs);
+		gtk_object_unref (GTK_OBJECT (applier->private->preview_prefs));
 
 	if (applier->private->wallpaper_pixbuf != NULL)
 		gdk_pixbuf_unref (applier->private->wallpaper_pixbuf);
@@ -337,22 +302,24 @@ applier_destroy (GtkObject *object)
 }
 
 void
-applier_apply_prefs (Applier *applier, Bonobo_PropertyBag pb, Bonobo_ConfigDatabase db, CORBA_Environment *ev, gboolean do_root, gboolean do_preview)
+applier_apply_prefs (Applier *applier, Preferences *prefs,
+		     gboolean do_root, gboolean do_preview)
 {
-	ApplierPreferences *prefs;
+	Preferences *new_prefs;
 
 	g_return_if_fail (applier != NULL);
 	g_return_if_fail (IS_APPLIER (applier));
 
 	if (do_root && applier->private->nautilus_running) {
 		set_root_pixmap (-1);
-		do_root = FALSE;
 	}
 
-	if (pb != CORBA_OBJECT_NIL)
-		prefs = applier_preferences_pb_new (pb, ev);
-	else
-		prefs = applier_preferences_db_new (db, ev);
+	if (!prefs->enabled) {
+		draw_disabled_message (applier_get_preview_widget (applier));
+		return;
+	}
+
+	new_prefs = PREFERENCES (preferences_clone (prefs));
 
 	if (((prefs->wallpaper_filename || 
 	      applier->private->wallpaper_filename) &&
@@ -372,7 +339,8 @@ applier_apply_prefs (Applier *applier, Bonobo_PropertyBag pb, Bonobo_ConfigDatab
 		applier->private->wallpaper_pixbuf = NULL;
 	}
 
-	if (prefs->wallpaper_filename && 
+	if (prefs->wallpaper_enabled &&
+	    prefs->wallpaper_filename && 
 	    (applier->private->wallpaper_filename == NULL ||
 	     strcmp (applier->private->wallpaper_filename, 
 		     prefs->wallpaper_filename)))
@@ -385,55 +353,61 @@ applier_apply_prefs (Applier *applier, Bonobo_PropertyBag pb, Bonobo_ConfigDatab
 		if (!applier->private->wallpaper_pixbuf) {
 			g_warning (_("Could not load pixbuf \"%s\"; disabling wallpaper."),
 				   prefs->wallpaper_filename);
-			prefs->wallpaper_enabled = FALSE;
+			new_prefs->wallpaper_enabled = FALSE;
 		}
 	}
 	else if (applier->private->wallpaper_pixbuf == NULL) {
-		prefs->wallpaper_enabled = FALSE;
+		new_prefs->wallpaper_enabled = FALSE;
 	}
 
 	if (do_preview) {
 		if (applier->private->preview_renderer == NULL)
 			applier->private->preview_renderer = 
-				renderer_new (FALSE);
+				renderer_new (applier, FALSE);
 
 		run_render_pipeline (applier->private->preview_renderer,
 				     applier->private->preview_prefs, 
-				     prefs,
+				     new_prefs,
 				     applier->private->wallpaper_pixbuf);
 
 		if (applier->private->preview_prefs != NULL)
-			applier_preferences_unref (applier->private->preview_prefs);
+			gtk_object_unref (GTK_OBJECT
+					  (applier->private->preview_prefs));
 
-		applier->private->preview_prefs = prefs;
-		applier_preferences_ref (prefs);
+		applier->private->preview_prefs = new_prefs;
+		gtk_object_ref (GTK_OBJECT (new_prefs));
 
-		if (preview_widget != NULL)
-			gtk_widget_queue_draw (preview_widget);
+		if (applier->private->preview_widget != NULL)
+			gtk_widget_queue_draw (applier->private->preview_widget);
 	}
 
 	if (do_root) {
 		nice (20);
 
 		if (applier->private->root_renderer == NULL)
-			applier->private->root_renderer = renderer_new (TRUE);
+			applier->private->root_renderer = renderer_new (applier, TRUE);
 
-		run_render_pipeline (applier->private->root_renderer,
-				     applier->private->root_prefs, 
-				     prefs,
-				     applier->private->wallpaper_pixbuf);
+		if (!applier->private->nautilus_running)
+			run_render_pipeline (applier->private->root_renderer,
+					     applier->private->root_prefs, 
+					     new_prefs,
+					     applier->private->wallpaper_pixbuf);
+
+		output_compat_prefs (prefs);
 
 		if (applier->private->root_prefs != NULL)
-			applier_preferences_unref (applier->private->root_prefs);
-		applier->private->root_prefs = prefs;
-		applier_preferences_ref (prefs);
+			gtk_object_unref (GTK_OBJECT 
+					  (applier->private->root_prefs));
+		
+		applier->private->root_prefs = new_prefs;
+		gtk_object_ref (GTK_OBJECT (new_prefs));
 	}
 
-	applier_preferences_unref (prefs);
+	gtk_object_unref (GTK_OBJECT (new_prefs));
 }
 
 GtkWidget *
-applier_class_get_preview_widget (void) 
+applier_get_preview_widget (Applier *applier) 
 {
 	GdkPixbuf *pixbuf;
 	GdkPixmap *pixmap;
@@ -444,7 +418,7 @@ applier_class_get_preview_widget (void)
 	gchar *filename;
 	GdkGC *gc;
 
-	if (preview_widget != NULL) return preview_widget;
+	if (applier->private->preview_widget != NULL) return applier->private->preview_widget;
 
 	filename = gnome_pixmap_file ("monitor.png");
 	visual = gdk_window_get_visual (GDK_ROOT_PARENT ());
@@ -503,25 +477,15 @@ applier_class_get_preview_widget (void)
 		mask = NULL;
 	}
 
-	preview_widget = gtk_pixmap_new (pixmap, mask);
-	gtk_widget_show (preview_widget);
+	applier->private->preview_widget = gtk_pixmap_new (pixmap, mask);
+	gtk_widget_show (applier->private->preview_widget);
 	gdk_pixbuf_unref (pixbuf);
 	g_free (filename);
 
 	gtk_widget_pop_visual ();
 	gtk_widget_pop_colormap ();
 
-	return preview_widget;
-}
-
-void
-applier_class_destroy_preview_widget (void)
-{
-	if (!preview_widget)
-		return;
-	if (GTK_IS_WIDGET (preview_widget))
-		gtk_widget_destroy (preview_widget);
-	preview_widget = NULL;
+	return applier->private->preview_widget;
 }
 
 static void
@@ -571,8 +535,8 @@ draw_disabled_message (GtkWidget *widget)
 
 static void
 run_render_pipeline (Renderer *renderer, 
-		     ApplierPreferences *old_prefs,
-		     ApplierPreferences *new_prefs,
+		     Preferences *old_prefs,
+		     Preferences *new_prefs,
 		     GdkPixbuf *wallpaper_pixbuf)
 {
 	gboolean bg_formed = FALSE;
@@ -631,7 +595,7 @@ run_render_pipeline (Renderer *renderer,
 }
 
 static Renderer *
-renderer_new (gboolean is_root) 
+renderer_new (Applier *applier, gboolean is_root) 
 {
 	Renderer *renderer;
 
@@ -646,8 +610,10 @@ renderer_new (gboolean is_root)
 		renderer->pixmap = 0;
 		renderer->is_set = FALSE;
 	} else {
-		if (!GTK_WIDGET_REALIZED (preview_widget))
-			gtk_widget_realize (preview_widget);
+		renderer->widget = applier_get_preview_widget (applier);
+
+		if (!GTK_WIDGET_REALIZED (renderer->widget))
+			gtk_widget_realize (renderer->widget);
 
 		renderer->x = MONITOR_CONTENTS_X;
 		renderer->y = MONITOR_CONTENTS_Y;
@@ -655,7 +621,7 @@ renderer_new (gboolean is_root)
 		renderer->height = MONITOR_CONTENTS_HEIGHT;
 		renderer->pixmap = 
 			GDK_WINDOW_XWINDOW (GTK_PIXMAP 
-					    (preview_widget)->pixmap);
+					    (applier->private->preview_widget)->pixmap);
 		renderer->is_set = TRUE;
 	}
 
@@ -685,17 +651,17 @@ renderer_destroy (Renderer *renderer)
 }
 
 static void
-renderer_set_prefs (Renderer *renderer, ApplierPreferences *prefs) 
+renderer_set_prefs (Renderer *renderer, Preferences *prefs) 
 {
 	g_return_if_fail (renderer != NULL);
 
 	if (renderer->prefs)
-		applier_preferences_unref (renderer->prefs);
+		gtk_object_unref (GTK_OBJECT (renderer->prefs));
 
 	renderer->prefs = prefs;
 
 	if (prefs)
-		applier_preferences_ref (prefs);
+		gtk_object_ref (GTK_OBJECT (prefs));
 }
 
 static void
@@ -780,8 +746,6 @@ renderer_render_wallpaper (Renderer *renderer)
 			      &renderer->wwidth, &renderer->wheight,
 			      &renderer->srcx, &renderer->srcy);
 
-		renderer->pwidth = MAX (renderer->pwidth, renderer->wwidth);
-
 		if (renderer->prefs->wallpaper_type == WPTYPE_TILED &&
 		    renderer->wwidth != renderer->pwidth &&
 		    renderer->wheight != renderer->pheight)
@@ -867,7 +831,7 @@ renderer_render_wallpaper (Renderer *renderer)
 			}
 		}
 		else if (renderer->wwidth != renderer->pwidth ||
-			 renderer->wheight != renderer->pheight) 
+			 renderer->wheight != renderer->pheight)
 		{
 			if (render_gradient_p (renderer, renderer->prefs)) {
 				scalex = (gdouble) renderer->wwidth / 
@@ -878,9 +842,10 @@ renderer_render_wallpaper (Renderer *renderer)
 					(renderer->wallpaper_pixbuf,
 					 renderer->pixbuf,
 					 renderer->wx, renderer->wy,
-					 renderer->wwidth, 
-					 renderer->wheight,
-					 renderer->wx, renderer->wy,
+					 MIN (renderer->wwidth, renderer->width), 
+					 MIN (renderer->wheight, renderer->height),
+					 renderer->wx - renderer->srcx,
+					 renderer->wy - renderer->srcy,
 					 scalex, scaley,
 					 GDK_INTERP_BILINEAR);
 			} else {
@@ -906,8 +871,9 @@ renderer_render_wallpaper (Renderer *renderer)
 			if (render_gradient_p (renderer, renderer->prefs)) {
 				gdk_pixbuf_copy_area
 					(renderer->wallpaper_pixbuf,
-					 0, 0, 
-					 renderer->pwidth, renderer->pheight,
+					 renderer->srcx, renderer->srcy, 
+					 MIN (renderer->width, renderer->pwidth),
+					 MIN (renderer->height, renderer->pheight),
 					 renderer->pixbuf,
 					 renderer->wx, renderer->wy);
 			} else {
@@ -1016,7 +982,7 @@ renderer_render_to_screen (Renderer *renderer)
 			gdk_window_clear (GDK_ROOT_PARENT ());
 		} else {
 			gdk_color_alloc (gdk_window_get_colormap
-					 (preview_widget->window), 
+					 (renderer->widget->window), 
 					 renderer->prefs->color1);
 			gdk_gc_set_foreground (gc, renderer->prefs->color1);
 			XFillRectangle (GDK_DISPLAY (), renderer->pixmap, xgc, 
@@ -1129,13 +1095,13 @@ get_geometry (wallpaper_type_t wallpaper_type, GdkPixbuf *pixbuf,
 		if (vwidth < gdk_pixbuf_get_width (pixbuf) &&
 		    wallpaper_type == WPTYPE_CENTERED)
 		{
-			*srcx = (gdk_pixbuf_get_width (pixbuf) - vwidth) / 2;
-			*rwidth = dwidth;
+			*srcx = (gdk_pixbuf_get_width (pixbuf) - vwidth) * factor / 2;
+			*rwidth = (gdouble) gdk_pixbuf_get_width (pixbuf) * factor;
 		}
 		else
 		{
 			*srcx = 0;
-			*rwidth = gdk_pixbuf_get_width (pixbuf) * factor;
+			*rwidth = (gdouble) gdk_pixbuf_get_width (pixbuf) * factor;
 		}
 
 		if (dheight != vheight)
@@ -1147,8 +1113,8 @@ get_geometry (wallpaper_type_t wallpaper_type, GdkPixbuf *pixbuf,
 		if (vheight < gdk_pixbuf_get_height (pixbuf) &&
 		    wallpaper_type == WPTYPE_CENTERED)
 		{
-			*srcy = (gdk_pixbuf_get_height (pixbuf) - vheight) / 2;
-			*rheight = dheight;
+			*srcy = (gdk_pixbuf_get_height (pixbuf) - vheight) * factor / 2;
+			*rheight = gdk_pixbuf_get_height (pixbuf) * factor;
 		}
 		else
 		{
@@ -1246,7 +1212,7 @@ render_tiled_image (Pixmap pixmap, GC xgc, GdkPixbuf *pixbuf,
 /* Return TRUE if the gradient should be rendered, false otherwise */
 
 static gboolean
-render_gradient_p (Renderer *renderer, ApplierPreferences *prefs) 
+render_gradient_p (Renderer *renderer, Preferences *prefs) 
 {
 	return prefs->gradient_enabled &&
 		!(prefs->wallpaper_enabled &&
@@ -1260,7 +1226,7 @@ render_gradient_p (Renderer *renderer, ApplierPreferences *prefs)
 /* Return TRUE if we can optimize the rendering by using a small thin pixmap */
 
 static gboolean
-render_small_pixmap_p (ApplierPreferences *prefs) 
+render_small_pixmap_p (Preferences *prefs) 
 {
 	return prefs->gradient_enabled && !prefs->wallpaper_enabled;
 }
@@ -1413,120 +1379,39 @@ is_nautilus_running (void)
 	return running;
 }
 
-static gulong
-pb_get_value_ulong (Bonobo_PropertyBag bag, const gchar *prop)
-{
-	BonoboArg *arg;
-	gulong val;
-	
-	arg = bonobo_property_bag_client_get_value_any (bag, prop, NULL);
-	val = BONOBO_ARG_GET_GENERAL (arg, TC_ulong, CORBA_unsigned_long, NULL);
-	bonobo_arg_release (arg);
-	return val;
-}
-
-#define PB_GET_VALUE(v) (bonobo_property_bag_client_get_value_any (pb, (v), NULL))
-
-/* Probably has CORBA memory leaks */
-static ApplierPreferences*
-applier_preferences_pb_new (Bonobo_PropertyBag pb, CORBA_Environment *ev)
-{
-	ApplierPreferences *prefs = g_new0 (ApplierPreferences, 1);
-
-	prefs->orientation = pb_get_value_ulong (pb, "orientation");
-	if (prefs->orientation != ORIENTATION_SOLID)
-		prefs->gradient_enabled = TRUE;
-
-	prefs->wallpaper_type = pb_get_value_ulong (pb, "wallpaper_type");
-	prefs->wallpaper_filename = g_strdup (*((CORBA_char **)(PB_GET_VALUE ("wallpaper_filename"))->_value));
-	if (prefs->wallpaper_filename && strcmp (prefs->wallpaper_filename, "") != 0)
-		prefs->wallpaper_enabled = TRUE;
-	
-	prefs->color1 = bonobo_color_to_gdk ((Bonobo_Config_Color *)(PB_GET_VALUE ("color1"))->_value);
-	prefs->color2 = bonobo_color_to_gdk ((Bonobo_Config_Color *)(PB_GET_VALUE ("color2"))->_value);
-
-	prefs->opacity = BONOBO_ARG_GET_LONG (PB_GET_VALUE ("opacity"));
-	if (prefs->opacity != 100)
-		prefs->adjust_opacity = FALSE;
-
-	prefs->ref_count = 1;
-
-	return prefs;
-}
-
-#define DB_GET_VALUE(v) (bonobo_config_get_value (db, (v), NULL, NULL))
-
-static ApplierPreferences*
-applier_preferences_db_new (Bonobo_ConfigDatabase db, CORBA_Environment *ev)
-{
-	ApplierPreferences *prefs = g_new0 (ApplierPreferences, 1);
-
-	prefs->orientation = bonobo_config_get_ulong (db, "/main/orientation", NULL);
-	if (prefs->orientation != ORIENTATION_SOLID)
-		prefs->gradient_enabled = TRUE;
-
-	prefs->wallpaper_type = bonobo_config_get_ulong (db, "/main/wallpaper_type", NULL);
-	prefs->wallpaper_filename = g_strdup (*((CORBA_char **)(DB_GET_VALUE ("/main/wallpaper_filename"))->_value));
-	if (prefs->wallpaper_filename && strcmp (prefs->wallpaper_filename, "") != 0)
-		prefs->wallpaper_enabled = TRUE;
-	
-	prefs->color1 = bonobo_color_to_gdk ((Bonobo_Config_Color *)(DB_GET_VALUE ("/main/color1"))->_value);
-	prefs->color2 = bonobo_color_to_gdk ((Bonobo_Config_Color *)(DB_GET_VALUE ("/main/color2"))->_value);
-
-	prefs->opacity = BONOBO_ARG_GET_LONG (DB_GET_VALUE ("/main/opacity"));
-	if (prefs->opacity != 100)
-		prefs->adjust_opacity = FALSE;
-
-	prefs->ref_count = 1;
-
-	return prefs;
-}
 
 static void
-applier_preferences_ref (ApplierPreferences *prefs)
+output_compat_prefs (Preferences *prefs)
 {
-	g_return_if_fail (prefs != NULL);
+	gchar *color;
 	
-	prefs->ref_count++;
-}
+	gnome_config_pop_prefix ();
+	gnome_config_set_bool ("/Background/Default/Enabled", prefs->wallpaper_enabled);
+	gnome_config_set_string ("/Background/Default/wallpaper",
+				 (prefs->wallpaper_filename) ? prefs->wallpaper_filename : "none");
+	gnome_config_set_int ("/Background/Default/wallpaperAlign", prefs->wallpaper_type);
 
-static void
-applier_preferences_unref (ApplierPreferences *prefs)
-{
-	g_return_if_fail (prefs != NULL);
+	color = g_strdup_printf ("#%02x%02x%02x",
+		prefs->color1->red >> 8,
+		prefs->color1->green >> 8,
+		prefs->color1->blue >> 8);
+	gnome_config_set_string ("/Background/Default/color1", color);
+	g_free (color);
 
-	prefs->ref_count--;
-	if (prefs->ref_count < 1)
-		applier_preferences_free (prefs);
-}
+	color = g_strdup_printf ("#%02x%02x%02x",
+		prefs->color2->red >> 8,
+		prefs->color2->green >> 8,
+		prefs->color2->blue >> 8);
+	gnome_config_set_string ("/Background/Default/color2", color);
+	g_free (color);
 
-static void
-applier_preferences_free (ApplierPreferences *prefs)
-{
-	g_return_if_fail (prefs != NULL);
+	gnome_config_set_string ("/Background/Default/simple",
+		       		 (prefs->gradient_enabled) ? "gradient" : "solid");
+	gnome_config_set_string ("/Background/Default/gradient",
+				   (prefs->orientation == ORIENTATION_VERT) ? "vertical" : "horizontal");
 	
-	if (prefs->wallpaper_filename)
-		g_free (prefs->wallpaper_filename);
+	gnome_config_set_bool ("/Background/Default/adjustOpacity", prefs->adjust_opacity);
+	gnome_config_set_int ("/Background/Default/opacity", prefs->opacity);
 
-	if (prefs->color1)
-		g_free (prefs->color1);
-	if (prefs->color2)
-		g_free (prefs->color2);
-
-	g_free (prefs);
-}
-
-static GdkColor*
-bonobo_color_to_gdk (Bonobo_Config_Color *color)
-{
-	GdkColor *ret;
-	
-	g_return_val_if_fail (color != NULL, NULL);
-
-	ret = g_new0 (GdkColor, 1);
-	ret->red = color->r * 65535;
-	ret->green = color->g * 65535;
-	ret->blue = color->b * 65535;
-
-	return ret;
+	gnome_config_sync ();
 }
